summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--.expeditor/config.yml5
-rw-r--r--.expeditor/release.omnibus.yml6
-rw-r--r--CHANGELOG.md9
-rw-r--r--Gemfile.lock14
-rw-r--r--VERSION2
-rw-r--r--chef-bin/lib/chef-bin/version.rb2
-rw-r--r--chef-config/lib/chef-config/version.rb2
-rw-r--r--lib/chef/version.rb2
-rw-r--r--omnibus/README.md4
-rwxr-xr-xtasks/docs.rb126
10 files changed, 92 insertions, 80 deletions
diff --git a/.expeditor/config.yml b/.expeditor/config.yml
index 203f6cd924..715afdab9d 100644
--- a/.expeditor/config.yml
+++ b/.expeditor/config.yml
@@ -26,11 +26,14 @@ pipelines:
- verify:
public: true
- habitat/build
- - omnibus/release
+ - omnibus/release:
+ env:
+ - BUILD_OPTIONS: -l debug
- omnibus/adhoc:
definition: .expeditor/release.omnibus.yml
env:
- ADHOC: true
+ - BUILD_OPTIONS: -l debug
github:
# This deletes the GitHub PR branch after successfully merged into the release branch
diff --git a/.expeditor/release.omnibus.yml b/.expeditor/release.omnibus.yml
index edd03f7bf0..8c20a5c3aa 100644
--- a/.expeditor/release.omnibus.yml
+++ b/.expeditor/release.omnibus.yml
@@ -48,12 +48,6 @@ builder-to-testers-map:
- solaris-11-i86pc
solaris-11-sparc:
- solaris-11-sparc
- ubuntu-14.04-i386:
- - ubuntu-14.04-i386
- ubuntu-14.04-ppc64le:
- - ubuntu-14.04-ppc64le
- ubuntu-14.04-x86_64:
- - ubuntu-14.04-x86_64
ubuntu-16.04-x86_64:
- ubuntu-16.04-x86_64
- ubuntu-18.04-x86_64
diff --git a/CHANGELOG.md b/CHANGELOG.md
index 1b2803d00f..1467516ca0 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,15 +1,18 @@
<!-- usage documentation: http://expeditor-docs.es.chef.io/configuration/changelog/ -->
-<!-- latest_release 15.1.39 -->
-## [v15.1.39](https://github.com/chef/chef/tree/v15.1.39) (2019-07-02)
+<!-- latest_release 15.1.43 -->
+## [v15.1.43](https://github.com/chef/chef/tree/v15.1.43) (2019-07-08)
#### Merged Pull Requests
-- update bldr config with new hab package name [#8706](https://github.com/chef/chef/pull/8706) ([robbkidd](https://github.com/robbkidd))
+- Improve generation of docs site resource pages [#8718](https://github.com/chef/chef/pull/8718) ([tas50](https://github.com/tas50))
<!-- latest_release -->
<!-- release_rollup since=15.1.36 -->
### Changes not yet released to stable
#### Merged Pull Requests
+- Improve generation of docs site resource pages [#8718](https://github.com/chef/chef/pull/8718) ([tas50](https://github.com/tas50)) <!-- 15.1.43 -->
+- Deprecate Ubuntu-14 [#8712](https://github.com/chef/chef/pull/8712) ([jaymalasinha](https://github.com/jaymalasinha)) <!-- 15.1.42 -->
+- fixes for chefstyle bump [#8707](https://github.com/chef/chef/pull/8707) ([lamont-granquist](https://github.com/lamont-granquist)) <!-- 15.1.40 -->
- update bldr config with new hab package name [#8706](https://github.com/chef/chef/pull/8706) ([robbkidd](https://github.com/robbkidd)) <!-- 15.1.39 -->
- windows_task: Fix for :day option is not accepting integer value [#8705](https://github.com/chef/chef/pull/8705) ([vsingh-msys](https://github.com/vsingh-msys)) <!-- 15.1.38 -->
- Bump inspec-core to 4.6.9 [#8701](https://github.com/chef/chef/pull/8701) ([chef-ci](https://github.com/chef-ci)) <!-- 15.1.37 -->
diff --git a/Gemfile.lock b/Gemfile.lock
index df290ae886..546d9218e0 100644
--- a/Gemfile.lock
+++ b/Gemfile.lock
@@ -27,11 +27,11 @@ GIT
PATH
remote: .
specs:
- chef (15.1.39)
+ chef (15.1.43)
addressable
bcrypt_pbkdf (~> 1.0)
bundler (>= 1.10)
- chef-config (= 15.1.39)
+ chef-config (= 15.1.43)
chef-zero (>= 14.0.11)
diff-lcs (~> 1.2, >= 1.2.4)
ed25519 (~> 1.2)
@@ -57,11 +57,11 @@ PATH
train-core (~> 2.0, >= 2.0.12)
tty-screen (~> 0.6)
uuidtools (~> 2.1.5)
- chef (15.1.39-universal-mingw32)
+ chef (15.1.43-universal-mingw32)
addressable
bcrypt_pbkdf (~> 1.0)
bundler (>= 1.10)
- chef-config (= 15.1.39)
+ chef-config (= 15.1.43)
chef-zero (>= 14.0.11)
diff-lcs (~> 1.2, >= 1.2.4)
ed25519 (~> 1.2)
@@ -103,13 +103,13 @@ PATH
PATH
remote: chef-bin
specs:
- chef-bin (15.1.39)
- chef (= 15.1.39)
+ chef-bin (15.1.43)
+ chef (= 15.1.43)
PATH
remote: chef-config
specs:
- chef-config (15.1.39)
+ chef-config (15.1.43)
addressable
fuzzyurl
mixlib-config (>= 2.2.12, < 4.0)
diff --git a/VERSION b/VERSION
index 0f5e15ba02..ff3e412450 100644
--- a/VERSION
+++ b/VERSION
@@ -1 +1 @@
-15.1.39 \ No newline at end of file
+15.1.43 \ No newline at end of file
diff --git a/chef-bin/lib/chef-bin/version.rb b/chef-bin/lib/chef-bin/version.rb
index a4c25d2a28..a33ee5635f 100644
--- a/chef-bin/lib/chef-bin/version.rb
+++ b/chef-bin/lib/chef-bin/version.rb
@@ -21,7 +21,7 @@
module ChefBin
CHEFBIN_ROOT = File.expand_path("../..", __FILE__)
- VERSION = "15.1.39".freeze
+ VERSION = "15.1.43".freeze
end
#
diff --git a/chef-config/lib/chef-config/version.rb b/chef-config/lib/chef-config/version.rb
index c20f2d70be..e5659a4fc3 100644
--- a/chef-config/lib/chef-config/version.rb
+++ b/chef-config/lib/chef-config/version.rb
@@ -21,7 +21,7 @@
module ChefConfig
CHEFCONFIG_ROOT = File.expand_path("../..", __FILE__)
- VERSION = "15.1.39".freeze
+ VERSION = "15.1.43".freeze
end
#
diff --git a/lib/chef/version.rb b/lib/chef/version.rb
index 2c37b464e6..971f26fa28 100644
--- a/lib/chef/version.rb
+++ b/lib/chef/version.rb
@@ -23,7 +23,7 @@ require_relative "version_string"
class Chef
CHEF_ROOT = File.expand_path("../..", __FILE__)
- VERSION = Chef::VersionString.new("15.1.39")
+ VERSION = Chef::VersionString.new("15.1.43")
end
#
diff --git a/omnibus/README.md b/omnibus/README.md
index aa58d6da5e..34e503519f 100644
--- a/omnibus/README.md
+++ b/omnibus/README.md
@@ -67,7 +67,7 @@ The default build environment requires Test Kitchen and VirtualBox for local dev
Once you have tweaked your `kitchen.yml` (or `kitchen.local.yml`) to your liking, you can bring up an individual build environment using the `kitchen` command.
```shell
-$ bundle exec kitchen converge chef-ubuntu-1404
+$ bundle exec kitchen converge chef-ubuntu-1604
```
Additional settings are required if using the kitchen-vagrant driver with the Hyper-V provider:
@@ -87,7 +87,7 @@ $ bundle exec kitchen login <PROJECT>-ubuntu-1204
```
```shell
-$ kitchen login chef-ubuntu-1404
+$ kitchen login chef-ubuntu-1604
[vagrant@ubuntu...] $ source load-omnibus-toolchain.sh
[vagrant@ubuntu...] $ cd chef/omnibus
[vagrant@ubuntu...] $ bundle install --without development # Don't install dev tools!
diff --git a/tasks/docs.rb b/tasks/docs.rb
index 0adebce0b6..c74bc55523 100755
--- a/tasks/docs.rb
+++ b/tasks/docs.rb
@@ -11,6 +11,13 @@ namespace :docs_site do
require "erb"
require "fileutils"
+ # @param version String
+ # @return String Chef Infra Client or Chef Client depending on version
+ def branded_chef_client_name(version)
+ return "Chef Infra Client" if Gem::Version.new(version) >= Gem::Version.new("15")
+ "Chef Client"
+ end
+
# @return [String, nil] a pretty defaul value string or nil if we want to skip it
def pretty_default(default)
return nil if default.nil? || default == "" || default == "lazy default"
@@ -139,7 +146,7 @@ namespace :docs_site do
``sensitive``
**Ruby Type:** true, false | **Default Value:** ``false``
- Ensure that sensitive resource data is not logged by the Chef Infra Client.
+ Ensure that sensitive resource data is not logged by Chef Infra Client.
.. end_tag
@@ -256,61 +263,65 @@ namespace :docs_site do
end
template = %{=====================================================
- <%= @name %> resource
- =====================================================
- `[edit on GitHub] <https://github.com/chef/chef-web-docs/blob/master/chef_master/source/resource_<%= @name %>.rst>`__
-
- <%= bolded_description(@name, @description) %>
- <%= note_text(@description) %>
- <% unless @introduced.nil? %>
- **New in Chef Infra Client <%= @introduced %>.**
- <% end %>
- Syntax
- =====================================================
- The <%= @name %> resource has the following syntax:
-
- .. code-block:: ruby
-
- <%= @resource_block %>
-
- where:
-
- * ``<%= @name %>`` is the resource.
- * ``name`` is the name given to the resource block.
- * ``action`` identifies which steps the Chef Infra Client will take to bring the node into the desired state.
- <% unless @property_list.nil? %>* <%= @property_list %><% end %>
-
- Actions
- =====================================================
-
- The <%= @name %> resource has the following actions:
- <% @actions.each do |a| %>
- ``:<%= a %>``
- <% if a == @default_action %>Default. <% end %>Description here.
- <% end %>
- ``:nothing``
- .. tag resources_common_actions_nothing
-
- This resource block does not act unless notified by another resource to take action. Once notified, this resource block either runs immediately or is queued up to run at the end of the Chef Infra Client run.
-
- .. end_tag
-
- Properties
- =====================================================
-
- The <%= @name %> resource has the following properties:
- <% @properties.each do |p| %>
- ``<%= p['name'] %>``
- **Ruby Type:** <%= friendly_types_list(p['is']) %><% unless pretty_default(p['default']).nil? %> | **Default Value:** ``<%= pretty_default(p['default']) %>``<% end %><% if p['required'] %> | ``REQUIRED``<% end %><% if p['deprecated'] %> | ``DEPRECATED``<% end %><% if p['name_property'] %> | **Default Value:** ``The resource block's name``<% end %>
-
- <%= p['description'] %>
- <% unless p['introduced'].nil? %>\n *New in Chef Infra Client <%= p['introduced'] %>.*<% end %>
- <% end %>
- <% if @properties.empty? %>This resource does not have any properties.\n<% end %>
- <%= boilerplate_content %>
- Examples
- ==========================================
- }
+<%= @name %> resource
+=====================================================
+`[edit on GitHub] <https://github.com/chef/chef-web-docs/blob/master/chef_master/source/resource_<%= @name %>.rst>`__
+
+<%= bolded_description(@name, @description) %>
+<%= note_text(@description) -%>
+<% unless @introduced.nil? -%>
+
+**New in <%= branded_chef_client_name(@introduced) %> <%= @introduced %>.**
+<% end -%>
+
+Syntax
+=====================================================
+
+The <%= @name %> resource has the following syntax:
+
+.. code-block:: ruby
+
+<%= @resource_block %>
+
+where:
+
+* ``<%= @name %>`` is the resource.
+* ``name`` is the name given to the resource block.
+* ``action`` identifies which steps Chef Infra Client will take to bring the node into the desired state.
+<% unless @property_list.nil? %>* <%= @property_list %><% end %>
+
+Actions
+=====================================================
+
+The <%= @name %> resource has the following actions:
+<% @actions.each do |a| %>
+``:<%= a %>``
+ <% if a == @default_action %>Default. <% end %>Description here.
+<% end %>
+``:nothing``
+ .. tag resources_common_actions_nothing
+
+ This resource block does not act unless notified by another resource to take action. Once notified, this resource block either runs immediately or is queued up to run at the end of the Chef Infra Client run.
+
+ .. end_tag
+
+Properties
+=====================================================
+
+The <%= @name %> resource has the following properties:
+<% @properties.each do |p| %>
+``<%= p['name'] %>``
+ **Ruby Type:** <%= friendly_types_list(p['is']) %><% unless pretty_default(p['default']).nil? %> | **Default Value:** ``<%= pretty_default(p['default']) %>``<% end %><% if p['required'] %> | ``REQUIRED``<% end %><% if p['deprecated'] %> | ``DEPRECATED``<% end %><% if p['name_property'] %> | **Default Value:** ``The resource block's name``<% end %>
+
+ <%= p['description'] %>
+<% unless p['introduced'].nil? -%>\n *New in <%= branded_chef_client_name(@introduced) %> <%= p['introduced'] -%>.*<% end -%>
+<% end %>
+<% if @properties.empty? %>This resource does not have any properties.\n<% end -%>
+<%= boilerplate_content %>
+Examples
+==========================================
+<%= @examples -%>
+}
FileUtils.mkdir_p "docs_site"
resources = Chef::JSONCompat.parse(ResourceInspector.inspect)
@@ -327,8 +338,9 @@ namespace :docs_site do
@properties = data["properties"].reject { |v| v["name"] == "name" }.sort_by! { |v| v["name"] }
@resource_block = generate_resource_block(resource, @properties)
@property_list = friendly_properly_list(@properties)
+ @examples = data["examples"]
- t = ERB.new(template)
+ t = ERB.new(template, nil, "-")
File.open("docs_site/resource_#{@name}.rst", "w") do |f|
f.write t.result(binding)
end